/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.core;

import java.io.File;
import java.io.IOException;
import java.net.URL;

import org.eclipse.core.runtime.FileLocator;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Plugin;
import org.eclipse.core.runtime.Status;

/**
 * 抽象 Benten プラグインです。
 */
public abstract class AbstractBentenPlugin extends Plugin {

	/**
	 * プラグイン id を取得します。
	 * @return プラグイン id
	 */
	public String getPluginId() {
		return getClass().getPackage().getName();
	}

	/**
	 * 指定されたメッセージをログ出力します。
	 * @param message ログ出力するメッセージ
	 */
	public void log(String message) {
		getLog().log(new Status(IStatus.WARNING, getPluginId(), message));
		System.out.println(message);
	}

	/**
	 * 指定された例外をログ出力します。
	 * @param e 例外
	 */
	public void log(final Throwable e) {
		getLog().log(new Status(IStatus.WARNING, getPluginId(), -1, e.toString(), e));
		e.printStackTrace();
	}

	/**
	 * このプラグイン配下のファイルを取得します。
	 * @param path パス
	 * @return ファイル。存在しない場合やアクセスできない場合は null。
	 */
	public File getFile(String path) {
		try {
			final URL entry = getBundle().getEntry(path);
			return new File(FileLocator.resolve(entry).getPath());
		} catch (final IOException e) {
			log(e);
			return null;
		}
	}
}
